@@ -9,6 +9,8 @@ import publication
 import typing_extensions
 
 import aws_cdk.aws_codebuild._jsii
+import aws_cdk.aws_events._jsii
+import aws_cdk.aws_events_targets._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
@@ -18,7 +20,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-prowler", "1.117.1", __name__[0:-6], "cdk-prowler@1.117.1.jsii.tgz"
+    "cdk-prowler", "1.117.4", __name__[0:-6], "cdk-prowler@1.117.4.jsii.tgz"
 )
 
 __all__ = [
